%--------------------------------------------------------------------------
% Calculate the model output and its sensitivities w.r.t. parameters  
%--------------------------------------------------------------------------
function [y,dyda,d2ydada] = fun_solve_poly(a,x)

% Extract number of parameters
N_a = length(a);
% Calculate the model value
y = polyval(a,x);
% Calculate dyda
method = 'vectorized';
switch method
    case 'serial'
        % Evaluate dsda with a loop (left in for clarity)
        dyda = NaN(N_a,1);
        for n = 1:N_a
            dyda(n) = x.^(N_a-n);
        end
    case 'vectorized'
        % Evaluate dsda in one line (quicker)
        dyda = x.^(N_a-(1:N_a)');
end
% Calculate d2y/dada (zeros for polynomials, which are linear in the parameters)
d2ydada = zeros(N_a);

end
