function [] = prior_MC()
% Investigate the distribution of ground truth parameters using MC

% Set the number of Monte Carlo samples
N_MC = 10000; 
% Set the order of the ground truth polynomial
N_gt = 5;
% Reset the random seed (optional)
% rng(1);

% Pre-allocate
a_gt = NaN(N_MC,N_gt+1);
% Generate ground truth parameters, a_gt, from a polynomial of a user-defined order
for n_MC = 1:N_MC
    % Generate some random data
    x_ref = -0.5:0.02:0.5; n_ref = numel(x_ref); y_ref = randn(n_ref,1);
    % Find the coefficients of an order N_gt polynomial that fits this data
    a_gt(n_MC,:) = polyfit(x_ref,y_ref,N_gt);
end

% Calculate mean
a_gt_E = mean(a_gt);
% Calculate variance
a_gt_V = var(a_gt);

fprintf('--------------------------------------------------------------- \n')
fprintf('Monte Carlo of %u samples to get distribution of gt param vals \n',N_MC)
fprintf('--------------------------------------------------------------- \n')
fprintf(['parameter     :',repmat('   a(%u)  ',1,N_gt+1),'\n'],1:N_gt+1)
fprintf(['     mean(a)  :',repmat('%0+7.4f  ',1,N_gt+1),'\n'],a_gt_E)
fprintf(['log{ var(a) } :',repmat('%0+7.4f  ',1,N_gt+1),'\n'],log(a_gt_V))
fprintf(['   2*(N:-1:0) :',repmat('%0+7.4f  ',1,N_gt+1),'\n'],2*(N_gt:-1:0))
